import _extends from "@babel/runtime/helpers/esm/extends";
import { createRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { highlightText } from '@s-ui/js/lib/string';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
import handlersFactory from './handlersFactory/index.js';
import { BASE_CLASS, CLASS_CHECKBOX, MODIFIER_TWO_LINES, MODIFIER_THREE_LINES, MODIFIER_NO_WRAP, MODIFIER_LINE_WRAP, CLASS_TEXT, CLASS_DESCRIPTION, CLASS_DISABLED, CLASS_HIGHLIGHTED, CLASS_HIGHLIGHTED_MARK, TEXT_WRAP_STYLES, CLASS_WITH_DESCRIPTION } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeDropdownOption = function MoleculeDropdownOption(_ref) {
  var _cx;

  var checkbox = _ref.checkbox,
      checkboxProps = _ref.checkboxProps,
      children = _ref.children,
      disabled = _ref.disabled,
      highlightQuery = _ref.highlightQuery,
      highlightValue = _ref.highlightValue,
      innerRef = _ref.innerRef,
      onSelectKey = _ref.onSelectKey,
      onSelect = _ref.onSelect,
      selected = _ref.selected,
      textWrap = _ref.textWrap,
      value = _ref.value,
      description = _ref.description,
      withTwoLinesText = _ref.withTwoLinesText;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_CHECKBOX] = checkbox, _cx[CLASS_DISABLED] = disabled, _cx[CLASS_WITH_DESCRIPTION] = description, _cx['is-selected'] = selected, _cx));
  var innerClassName = cx([CLASS_TEXT, (withTwoLinesText || textWrap === TEXT_WRAP_STYLES.TWO_LINES) && CLASS_TEXT + "--" + MODIFIER_TWO_LINES, textWrap === TEXT_WRAP_STYLES.THREE_LINES && CLASS_TEXT + "--" + MODIFIER_THREE_LINES, textWrap === TEXT_WRAP_STYLES.LINE_WRAP && CLASS_TEXT + "--" + MODIFIER_LINE_WRAP, (!withTwoLinesText && !textWrap || textWrap === TEXT_WRAP_STYLES.NO_WRAP) && CLASS_TEXT + "--" + MODIFIER_NO_WRAP]);

  var _handlersFactory = handlersFactory({
    disabled: disabled,
    onSelectKey: onSelectKey,
    onSelect: onSelect,
    value: value
  }),
      handleClick = _handlersFactory.handleClick,
      handleKeyDown = _handlersFactory.handleKeyDown,
      handleFocus = _handlersFactory.handleFocus;

  var renderHighlightOption = function renderHighlightOption(option) {
    if (typeof option !== 'string') {
      return /*#__PURE__*/_jsx("span", {
        onFocus: handleInnerFocus,
        className: innerClassName,
        children: option
      });
    }

    var mark = highlightText({
      value: option,
      query: highlightQuery,
      startTag: "<mark class=\"" + cx(CLASS_HIGHLIGHTED_MARK, CLASS_HIGHLIGHTED) + "\">",
      endTag: '</mark>'
    });
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx("span", {
        onFocus: handleInnerFocus,
        dangerouslySetInnerHTML: {
          __html: mark
        },
        className: innerClassName
      }), highlightValue ? children : null]
    });
  };

  var handleInnerFocus = function handleInnerFocus(ev) {
    ev.preventDefault();
    innerRef.current.focus();
  };

  return /*#__PURE__*/_jsxs("li", {
    ref: innerRef,
    tabIndex: "0",
    className: className,
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    onFocus: handleFocus,
    role: "option",
    children: [checkbox && /*#__PURE__*/_jsx(AtomCheckbox, _extends({
      checked: selected,
      disabled: disabled,
      onFocus: handleInnerFocus
    }, checkboxProps)), highlightQuery ? renderHighlightOption(highlightValue || children) : /*#__PURE__*/_jsx("span", {
      onFocus: handleInnerFocus,
      className: innerClassName,
      children: children
    }), description && /*#__PURE__*/_jsx("span", {
      className: CLASS_DESCRIPTION,
      children: description
    })]
  });
};

MoleculeDropdownOption.displayName = 'MoleculeDropdownOption';
MoleculeDropdownOption.defaultProps = {
  checkbox: false,
  disabled: false,
  onSelect: function onSelect() {},
  selected: false,
  onSelectKey: 'Enter',
  innerRef: /*#__PURE__*/createRef()
};
export default MoleculeDropdownOption;
export { handlersFactory };
export { TEXT_WRAP_STYLES as MoleculeDropdownOptionTextWrapStyles };